@@ -3,7 +3,7 @@
 /*
     Rubber Band Library
     An audio time-stretching and pitch-shifting library.
-    Copyright 2007-2020 Particular Programs Ltd.
+    Copyright 2007-2021 Particular Programs Ltd.
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -21,17 +21,24 @@
     you must obtain a valid commercial licence before doing so.
 */
 
-#ifndef _RUBBERBAND_C_API_H_
-#define _RUBBERBAND_C_API_H_
+#ifndef RUBBERBAND_C_API_H
+#define RUBBERBAND_C_API_H
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#define RUBBERBAND_VERSION "1.9.0"
+#define RUBBERBAND_VERSION "1.9.2"
 #define RUBBERBAND_API_MAJOR_VERSION 2
 #define RUBBERBAND_API_MINOR_VERSION 6
 
+#undef RB_EXTERN
+#ifdef _MSC_VER
+#define RB_EXTERN extern __declspec(dllexport)
+#else
+#define RB_EXTERN extern
+#endif
+
 /**
  * This is a C-linkage interface to the Rubber Band time stretcher.
  * 
@@ -83,7 +90,7 @@ enum RubberBandOption {
     RubberBandOptionPitchHighConsistency = 0x04000000,
 
     RubberBandOptionChannelsApart        = 0x00000000,
-    RubberBandOptionChannelsTogether     = 0x10000000,
+    RubberBandOptionChannelsTogether     = 0x10000000
 };
 
 typedef int RubberBandOptions;
@@ -91,52 +98,54 @@ typedef int RubberBandOptions;
 struct RubberBandState_;
 typedef struct RubberBandState_ *RubberBandState;
 
-extern RubberBandState rubberband_new(unsigned int sampleRate,
+RB_EXTERN RubberBandState rubberband_new(unsigned int sampleRate,
                                       unsigned int channels,
                                       RubberBandOptions options,
                                       double initialTimeRatio,
                                       double initialPitchScale);
 
-extern void rubberband_delete(RubberBandState);
+RB_EXTERN void rubberband_delete(RubberBandState);
 
-extern void rubberband_reset(RubberBandState);
+RB_EXTERN void rubberband_reset(RubberBandState);
 
-extern void rubberband_set_time_ratio(RubberBandState, double ratio);
-extern void rubberband_set_pitch_scale(RubberBandState, double scale);
+RB_EXTERN void rubberband_set_time_ratio(RubberBandState, double ratio);
+RB_EXTERN void rubberband_set_pitch_scale(RubberBandState, double scale);
 
-extern double rubberband_get_time_ratio(const RubberBandState);
-extern double rubberband_get_pitch_scale(const RubberBandState);
+RB_EXTERN double rubberband_get_time_ratio(const RubberBandState);
+RB_EXTERN double rubberband_get_pitch_scale(const RubberBandState);
 
-extern unsigned int rubberband_get_latency(const RubberBandState);
+RB_EXTERN unsigned int rubberband_get_latency(const RubberBandState);
 
-extern void rubberband_set_transients_option(RubberBandState, RubberBandOptions options);
-extern void rubberband_set_detector_option(RubberBandState, RubberBandOptions options);
-extern void rubberband_set_phase_option(RubberBandState, RubberBandOptions options);
-extern void rubberband_set_formant_option(RubberBandState, RubberBandOptions options);
-extern void rubberband_set_pitch_option(RubberBandState, RubberBandOptions options);
+RB_EXTERN void rubberband_set_transients_option(RubberBandState, RubberBandOptions options);
+RB_EXTERN void rubberband_set_detector_option(RubberBandState, RubberBandOptions options);
+RB_EXTERN void rubberband_set_phase_option(RubberBandState, RubberBandOptions options);
+RB_EXTERN void rubberband_set_formant_option(RubberBandState, RubberBandOptions options);
+RB_EXTERN void rubberband_set_pitch_option(RubberBandState, RubberBandOptions options);
 
-extern void rubberband_set_expected_input_duration(RubberBandState, unsigned int samples);
+RB_EXTERN void rubberband_set_expected_input_duration(RubberBandState, unsigned int samples);
 
-extern unsigned int rubberband_get_samples_required(const RubberBandState);
+RB_EXTERN unsigned int rubberband_get_samples_required(const RubberBandState);
 
-extern void rubberband_set_max_process_size(RubberBandState, unsigned int samples);
-extern void rubberband_set_key_frame_map(RubberBandState, unsigned int keyframecount, unsigned int *from, unsigned int *to);
+RB_EXTERN void rubberband_set_max_process_size(RubberBandState, unsigned int samples);
+RB_EXTERN void rubberband_set_key_frame_map(RubberBandState, unsigned int keyframecount, unsigned int *from, unsigned int *to);
 
-extern void rubberband_study(RubberBandState, const float *const *input, unsigned int samples, int final);
-extern void rubberband_process(RubberBandState, const float *const *input, unsigned int samples, int final);
+RB_EXTERN void rubberband_study(RubberBandState, const float *const *input, unsigned int samples, int final);
+RB_EXTERN void rubberband_process(RubberBandState, const float *const *input, unsigned int samples, int final);
 
-extern int rubberband_available(const RubberBandState);
-extern unsigned int rubberband_retrieve(const RubberBandState, float *const *output, unsigned int samples);
+RB_EXTERN int rubberband_available(const RubberBandState);
+RB_EXTERN unsigned int rubberband_retrieve(const RubberBandState, float *const *output, unsigned int samples);
 
-extern unsigned int rubberband_get_channel_count(const RubberBandState);
+RB_EXTERN unsigned int rubberband_get_channel_count(const RubberBandState);
 
-extern void rubberband_calculate_stretch(RubberBandState);
+RB_EXTERN void rubberband_calculate_stretch(RubberBandState);
 
-extern void rubberband_set_debug_level(RubberBandState, int level);
-extern void rubberband_set_default_debug_level(int level);
+RB_EXTERN void rubberband_set_debug_level(RubberBandState, int level);
+RB_EXTERN void rubberband_set_default_debug_level(int level);
 
 #ifdef __cplusplus
 }
 #endif
 
+#undef RB_EXTERN
+
 #endif
